@@ -9,9 +9,7 @@
     :license: MIT, see LICENSE for more details.
 """
 
-import datetime
-
-from pip_services3_commons.convert import TypeCode
+from pip_services3_commons.convert import TypeCode, TypeConverter, DateTimeConverter
 
 
 class TypeMatcher:
@@ -21,6 +19,7 @@ class TypeMatcher:
     This class has symmetric implementation across all languages supported
     by Pip.Services toolkit and used to support dynamic data processing.
     """
+
     @staticmethod
     def match_value(expected_type, actual_value):
         """
@@ -38,10 +37,10 @@ class TypeMatcher:
         if actual_value is None:
             raise Exception("Actual value cannot be null")
 
-        return TypeMatcher.match_type(expected_type, type(actual_value))
+        return TypeMatcher.match_type(expected_type, TypeConverter.to_type_code(actual_value), actual_value)
 
     @staticmethod
-    def match_type(expected_type, actual_type):
+    def match_type(expected_type, actual_type, actual_value=None):
         """
         Matches expected type to an actual type.
         The types can be specified as types, type names or :class:`TypeCode <pip_services3_commons.convert.TypeCode.TypeCode>`.
@@ -50,6 +49,8 @@ class TypeMatcher:
 
         :param actual_type: an actual type to match.
 
+        :param actual_value: an optional value to match its type to the expected one.
+
         :return: True if types are matching and False if they don't.
         """
         if expected_type is None:
@@ -58,29 +59,41 @@ class TypeMatcher:
             raise Exception("Actual type cannot be null")
 
         if isinstance(expected_type, type):
-            return issubclass(actual_type, expected_type)
+            return issubclass(type(actual_value), expected_type)
 
-        if isinstance(expected_type, str):
-            return TypeMatcher.match_type_by_name(expected_type, actual_type)
         if isinstance(expected_type, int):
             if expected_type == actual_type:
                 return True
+
             # Special provisions for dynamic data
-            if expected_type == TypeCode.Integer and (actual_type == TypeCode.Long or actual_type == TypeCode.Float or actual_type == TypeCode.Double):
+            if expected_type == TypeCode.Integer and (
+                    actual_type == TypeCode.Long or actual_type == TypeCode.Float or actual_type == TypeCode.Double):
                 return True
-            if expected_type == TypeCode.Long and (actual_type == TypeCode.Integer or actual_type == TypeCode.Float or actual_type == TypeCode.Double):
+
+            if expected_type == TypeCode.Long and (
+                    actual_type == TypeCode.Integer or actual_type == TypeCode.Float or actual_type == TypeCode.Double):
                 return True
-            if expected_type == TypeCode.Float and (actual_type == TypeCode.Integer or actual_type == TypeCode.Long or actual_type == TypeCode.Double):
+
+            if expected_type == TypeCode.Float and (
+                    actual_type == TypeCode.Integer or actual_type == TypeCode.Long or actual_type == TypeCode.Double):
                 return True
-            if expected_type == TypeCode.Double and (actual_type == TypeCode.Integer or actual_type == TypeCode.Long or actual_type == TypeCode.Float):
+
+            if expected_type == TypeCode.Double and (
+                    actual_type == TypeCode.Integer or actual_type == TypeCode.Long or actual_type == TypeCode.Float):
                 return True
-            # if expected_type == TypeCode.DateTime and (actual_type == TypeCode.String and DateTimeConverter.toNullableDateTime(actualValue) != null):
-            #     return True
+
+            if expected_type == TypeCode.DateTime and (
+                    actual_type == TypeCode.String
+                    and DateTimeConverter.to_nullable_datetime(actual_value) is not None):
+                return True
+
+        if isinstance(expected_type, str):
+            return TypeMatcher.match_type_by_name(expected_type, actual_type, actual_value)
 
         return False
 
     @staticmethod
-    def match_value_by_name(expected_type, actual_value):
+    def match_value_type_by_name(expected_type, actual_value):
         """
         Matches expected type to a type of a value.
 
@@ -95,10 +108,10 @@ class TypeMatcher:
         if actual_value is None:
             raise Exception("Actual value cannot be null")
 
-        return TypeMatcher.match_type_by_name(expected_type, type(actual_value))
+        return TypeMatcher.match_type_by_name(expected_type, TypeConverter.to_type_code(actual_value), actual_value)
 
     @staticmethod
-    def match_type_by_name(expected_type, actual_type):
+    def match_type_by_name(expected_type, actual_type, actual_value=None):
         """
         Matches expected type to an actual type.
 
@@ -106,41 +119,57 @@ class TypeMatcher:
 
         :param actual_type: an actual type to match defined by type code.
 
+        :param actual_value: an optional value to match its type to the expected one.
+
         :return: true if types are matching and false if they don't.
         """
         if expected_type is None:
             return True
         if actual_type is None:
             raise Exception("Actual type cannot be null")
-        
+
         expected_type = expected_type.lower()
 
-        if actual_type.__name__.lower() == expected_type: 
+        if type(actual_value).__name__.lower() == expected_type:
             return True
-        elif expected_type == "object":
+
+        if expected_type == "object":
             return True
         elif expected_type == "int" or expected_type == "integer":
-            return issubclass(actual_type, int) #or issubclass(actual_type, long)
+            # Special provisions for dynamic data
+            return actual_type == TypeCode.Integer or actual_type == TypeCode.Long
         elif expected_type == "long":
-            return issubclass(actual_type, int)
+            # Special provisions for dynamic data
+            return actual_type == TypeCode.Long or actual_type == TypeCode.Integer
         elif expected_type == "float" or expected_type == "double":
-            return issubclass(actual_type, float)
+            # Special provisions for dynamic data
+            return actual_type == TypeCode.Float \
+                   or actual_type == TypeCode.Double \
+                   or actual_type == TypeCode.Integer \
+                   or actual_type == TypeCode.Long
         elif expected_type == "string":
-            return issubclass(actual_type, str) #or issubclass(actual_type, unicode)
+            return actual_type == TypeCode.String
         elif expected_type == "bool" or expected_type == "boolean":
-            return issubclass(actual_type, bool)
+            return actual_type == TypeCode.Boolean
         elif expected_type == "date" or expected_type == "datetime":
-            return issubclass(actual_type, datetime.datetime) or issubclass(actual_type. datetime.date)
+            # Special provisions fro dynamic data
+            return actual_type == TypeCode.DateTime \
+                   or (actual_type == TypeCode.String
+                       and DateTimeConverter.to_nullable_datetime(actual_value) is not None)
         elif expected_type == "timespan" or expected_type == "duration":
-            return issubclass(actual_type, int) or issubclass(actual_type, float)
+            return actual_type == TypeCode.Integer \
+                   or actual_type == TypeCode.Long \
+                   or actual_type == TypeCode.Float \
+                   or actual_type == TypeCode.Double
         elif expected_type == "enum":
-            return issubclass(actual_type, str) or issubclass(actual_type, int)
+            return actual_type == TypeCode.Integer or actual_type == TypeCode.String
+
         elif expected_type == "map" or expected_type == "dict" or expected_type == "dictionary":
-            return issubclass(actual_type, dict)
+            return actual_type == TypeCode.Map
         elif expected_type == "array" or expected_type == "list":
-            return issubclass(actual_type, list) or issubclass(actual_type, tuple) or issubclass(actual_type, set)
+            return actual_type == TypeCode.Array
         elif expected_type.endswith("[]"):
             # Todo: Check subtype
-            return issubclass(actual_type, list) or issubclass(actual_type, tuple) or issubclass(actual_type, set)
+            return actual_type == TypeCode.Array
         else:
             return False
